package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

public final class SourceFile extends Attribute {
   private int sourceFileIndex;

   SourceFile(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
      this(nameIndex, length, input.readUnsignedShort(), constantPool);
   }

   public SourceFile(int nameIndex, int length, int sourceFileIndex, ConstantPool constantPool) {
      super((byte)0, nameIndex, length, constantPool);
      this.sourceFileIndex = sourceFileIndex;
   }

   public SourceFile(SourceFile c) {
      this(c.getNameIndex(), c.getLength(), c.getSourceFileIndex(), c.getConstantPool());
   }

   public void accept(Visitor v) {
      v.visitSourceFile(this);
   }

   public Attribute copy(ConstantPool constantPool) {
      return (Attribute)this.clone();
   }

   public void dump(DataOutputStream file) throws IOException {
      super.dump(file);
      file.writeShort(this.sourceFileIndex);
   }

   public int getSourceFileIndex() {
      return this.sourceFileIndex;
   }

   public String getSourceFileName() {
      return super.getConstantPool().getConstantUtf8(this.sourceFileIndex).getBytes();
   }

   public void setSourceFileIndex(int sourceFileIndex) {
      this.sourceFileIndex = sourceFileIndex;
   }

   public String toString() {
      return "SourceFile: " + this.getSourceFileName();
   }
}
